@@ -9,7 +9,7 @@ use feature ":5.10";
 use Config;
 use File::Spec::Functions qw(catdir rel2abs splitpath);
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 use constant DFLT_TOCOPY_SECTION  => "__TOCOPY__";
 
@@ -216,34 +216,47 @@ my $_parse_ini = sub {
     if ($modifier eq "") {
       delete $expanded->{$x_var_name} if $exp_flag;
       $sect_vars->{$var_name} = $value;
-    } elsif ($modifier eq '?') {
+    }
+    elsif ($modifier eq '?') {
       $sect_vars->{$var_name} = $value if !exists($sect_vars->{$var_name});
-    } elsif ($modifier eq '+') {
+    }
+    elsif ($modifier eq '??') {
+      $sect_vars->{$var_name} = $value if (!exists($sect_vars->{$var_name})
+                                           || $sect_vars->{$var_name} eq "");
+    }
+    elsif ($modifier eq '+') {
       if (exists($sect_vars->{$var_name})) {
         $sect_vars->{$var_name} .= " "
           . ($exp_flag ? $self->$_expand_value($curr_section, $value) : $value);
-      } else {
+      }
+      else {
         $sect_vars->{$var_name} = $value;
       }
-    } elsif ($modifier eq '.') {
+    }
+    elsif ($modifier eq '.') {
       $sect_vars->{$var_name} = ($sect_vars->{$var_name} // "")
         . ($exp_flag ? $self->$_expand_value($curr_section, $value) : $value);
-    } elsif ($modifier eq ':') {
+    }
+    elsif ($modifier eq ':') {
       delete $expanded->{$x_var_name} if $exp_flag; # Needed to make _expand_vars corectly!
       $sect_vars->{$var_name} = $self->$_expand_vars($curr_section, $var_name, $value, undef, 1);
-    } elsif ($modifier eq '+>') {
+    }
+    elsif ($modifier eq '+>') {
       if (exists($sect_vars->{$var_name})) {
         $sect_vars->{$var_name} =
           ($exp_flag ? $self->$_expand_value($curr_section, $value) : $value)
           . ' ' . $sect_vars->{$var_name};
-      } else {
+      }
+      else {
         $sect_vars->{$var_name} = $value;
       }
-    } elsif ($modifier eq '.>') {
+    }
+    elsif ($modifier eq '.>') {
       $sect_vars->{$var_name} =
         ($exp_flag ? $self->$_expand_value($curr_section, $value) : $value)
         . ($sect_vars->{$var_name} // "");
-    } else {
+    }
+    else {
       $_fatal->("'$modifier': unsupported modifier");
     }
   }
@@ -508,7 +521,7 @@ Config::INI::RefVars - INI file reader that supports make-style variable referen
 
 =head1 VERSION
 
-Version 0.14
+Version 0.15
 
 =head1 SYNOPSIS
 
@@ -685,6 +698,21 @@ variable simply overwrites the first.
 Works like the corresponding operator of GNU Make: the assignment is only
 executed if the variable is not yet defined.
 
+=item C<??=>
+
+This works similar to C<?=>: the assignment is only executed if the variable
+is not yet defined or if its current, non-expanded value is an empty string.
+
+This allows you to set a default value for an environment variable:
+
+   env_var:=$(=ENV:ENV_VAR)
+   env_var??=the default
+
+If the environment variable C<ENV_VAR> is not defined or is empty, then
+C<env_var> has the value C<the default>. This would not work with
+C<?=>. Please note that you must also use C<:=>!
+
+
 =item C<:=>
 
 Works like the corresponding operator of GNU Make: all references to other
